"use client";

import { getKycs } from "@/app/lib/kyc/action";
import { getStorage, setStorage } from "@/utils/navigation";
import { Box } from "@chakra-ui/react";
import { useEffect, useState, useCallback } from "react";
import CardList, { CardListProps } from "./components/card-list";

export interface KYCData {
  last_sync_at: string;
  data: CardListProps[];
}

const Page = () => {
  const [data, setData] = useState([]);
  const [loading, setLoading] = useState(false);

  const handleSync = useCallback(async () => {
    setLoading(true);
    setStorage("dcs", null);
    try {
      const res = await getKycs({ pagination: "false" });
      const syncData: KYCData = {
        last_sync_at: new Date().toISOString(),
        data: res || [],
      };

      setStorage("kycs", syncData);
      setData(syncData.data);
    } catch (error) {
      console.error("Error syncing kycs:", error);
    } finally {
      setLoading(false);
    }
  }, []);

  useEffect(() => {
    const getAllKycs = async () => {
      setLoading(true);
      try {
        const storedData = await getStorage("kycs");
        const isDataStale =
          !storedData?.last_sync_at ||
          Date.now() - new Date(storedData.last_sync_at).getTime() > 86400000;

        if (
          (storedData?.data && !isDataStale) ||
          storedData?.data?.some(
            (item: { offline: Boolean }) => item?.offline == true
          )
        ) {
          setData(storedData.data);
        } else {
          await handleSync();
        }
      } catch (error) {
        console.error("Error fetching kycs:", error);
      } finally {
        setLoading(false);
      }
    };

    getAllKycs();
  }, []);

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      <CardList data={data} isLoading={loading} handleSync={handleSync} />
    </Box>
  );
};

export default Page;
